"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hostStaticBootstrap = void 0;
const tslib_1 = require("tslib");
const http_1 = require("http");
const node_static_1 = tslib_1.__importDefault(require("node-static"));
const HOST_STATIC_RUN_MULTIPLE_KEY = 'HOST_STATIC_RUN_MULTIPLE_KEY';
const hostStaticBootstrap = ({ path, enabled = true, port = 3001, }) => {
    const folder = new node_static_1.default.Server(path);
    let server;
    const serveStatic = () => {
        if (!enabled) {
            return;
        }
        server = (0, http_1.createServer)((request, response) => {
            request
                .addListener('end', () => {
                folder.serve(request, response);
            })
                .resume();
        })
            .listen(port);
    };
    const killServer = () => {
        if (server) {
            server.close();
        }
    };
    ['SIGINT', 'SIGTERM', 'SIGQUIT']
        .forEach(signal => process.on(signal, killServer));
    return {
        bootstrap: () => {
            if (process.env[HOST_STATIC_RUN_MULTIPLE_KEY]) {
                return;
            }
            serveStatic();
        },
        teardown: () => {
            if (process.env[HOST_STATIC_RUN_MULTIPLE_KEY]) {
                return;
            }
            killServer();
        },
        bootstrapAll: () => {
            process.env[HOST_STATIC_RUN_MULTIPLE_KEY] = '1';
            serveStatic();
        },
        teardownAll: killServer,
    };
};
exports.hostStaticBootstrap = hostStaticBootstrap;
